from serial.tools.list_ports import comports

def get_port_list():
    return [p.device for p in comports()]

def detect_port_of_basic():
    """Detect M5 Basic.
    Returns the serial port string of the first detected M5 Basic.
    If it is not found, it returns `None`.
    """
    ports = [p.device for p in comports() if p.pid == 0xea60]
    return ports[0] if len(ports) > 0 else None



from __future__ import absolute_import

from pymycobot.mycobot import MyCobot
from pymycobot.generate import MycobotCommandGenerater
from pymycobot.genre import Angle, Coord
from pymycobot import utils

__all__ = ["MyCobot", "MycobotCommandGenerater", "Angle", "Coord", "utils"]

__version__ = "2.5.9"
__author__ = "Zachary zhang"
__email__ = "lijun.zhang@elephantrobotics.com"
__git_url__ = "https://github.com/elephantrobotics/pymycobot"

PI_PORT = "/dev/ttyAMA0"
PI_BAUD = 1000000
